@@ -1,4 +1,6 @@
 from functools import reduce
+from json import JSONEncoder, loads, dumps
+from datetime import datetime, date
 import operator
 
 
@@ -68,6 +70,10 @@ class ExecPeewee:
             insert_data.append(i)
         yield insert_data
 
+    @classmethod
+    def date_encoder(cls, data):
+        return loads(dumps(data, cls=DateEncoder))
+
     @classmethod
     def __clear_data(cls, insert_data: list):
         current_data = insert_data[:]
@@ -77,7 +83,7 @@ class ExecPeewee:
     @classmethod
     def __fork_upsert(cls, pw_table, data, primary, batch_size):
         rows, model_list = [], []
-        dids = set(i[primary] for i in data if i.get(primary))
+        dids = set(i[primary] for i in data if i.get(primary) or i.get(primary) == 0)
         exist_ids = cls.__record_exists(pw_table, dids)
         [model_list.append(i) if i.get(primary) in exist_ids else rows.append(i) for i in data]
         cls.__data_check(rows)
@@ -99,3 +105,16 @@ class ExecPeewee:
     def __check_result(cls, data: dict, simple: dict):
         if data.keys() != simple.keys():
             raise ValueError(f'keys not match: {data} VS {simple}')
+
+
+class DateEncoder(JSONEncoder):
+    """
+    TypeError: Object of type 'datetime' is not JSON serializable
+    """
+    def default(self, obj):
+        if isinstance(obj, datetime):
+            return obj.strftime('%Y-%m-%d %H:%M:%S')
+        elif isinstance(obj, date):
+            return obj.strftime("%Y-%m-%d")
+        else:
+            return JSONEncoder.default(self, obj)
